@@ -9,9 +9,11 @@
 
 /* .Call calls */
 extern SEXP R_mstep_cpp(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP REML_Rm_cpp(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
     {"R_mstep_cpp", (DL_FUNC) &R_mstep_cpp, 16},
+    {"REML_Rm_cpp",  (DL_FUNC) &REML_Rm_cpp,  18},
     {NULL, NULL, 0}
 };
 
